import {beforeAll, describe, expect, test} from '@jest/globals'
import {Utils} from '@/Utils/Utils'
import {PayError, Payment, PayType} from '@/Payment/Payment'
import {defaultRequest, DefaultResponse} from "@/Request/Request";
import {ACCESS_TOKEN, UID} from "@/Const";

const globalDatabase: any = {
    /**
     * 1块钱商品
     * https://testnewm.ydl.com/consult/#/pages/jieyou/DownOrder?product_id=88220606058062&uid=130959612&accessToken=33441f9c4be74a357b1d416d4aa616eaMjIwNw&ffrom=m
     */
    MOCK_GOODS: {
        productId: 88220606058062,
        productSpecs: [
            {
                standardProductSpecId: 255539,
                amount: 1
            }
        ],
        type: 1,
        totalPrice: 1
    }
}

const createOrder = async  ():Promise<{orderId: number, title: string, payId: number, money: number}> => {
    const res = await defaultRequest.post<any, DefaultResponse>('https://testapi.ydl.com/api/consult/user/order/submitWorriesConsultOrder', globalDatabase.MOCK_GOODS)
    return res.data
}

beforeAll(async () => {
    //
    /**
     * 测试账号：15706780002 ydl123456
     * 请保证账户余额为1.9元
     */
    Utils.setCookie(UID, '130959612')
    Utils.setCookie(ACCESS_TOKEN, '33441f9c4be74a357b1d416d4aa616eaMjIwNw')
    globalDatabase.payment = new Payment()
})

describe('测试用余额购买1块钱商品', () => {
    test('test：获取账户余额', async () => {
        const balance = await globalDatabase.payment.getBalance()
        expect(balance).toBeGreaterThanOrEqual(1)
    })

    test('test: 测试余额支付', async () => {
        const {orderId, money} = await createOrder()
        const res = await globalDatabase.payment.toPay({
            totalAmount: money,
            payType: PayType.BALANCE,
            orderId,
            redirectUrl: window.encodeURIComponent('https://www.baidu.com'),
            returnUrl: 'https://www.baidu.com',
            quitUrl: 'https://www.baidu.com'
        })
        expect(res.success).toBe(true)
    })
})

describe('测试用0.9元余额 + 0.1元支付宝金额支付', () => {
    test('test：获取账户余额', async () => {
        const balance = await globalDatabase.payment.getBalance()
        expect(balance).toBe(0.9)
    })
    test('test: 使用余额+支付宝支付', async () => {
        const {orderId, money} = await createOrder()
        const res = await globalDatabase.payment.toPay({
            totalAmount: money,
            payType: PayType.ALIPAY_BALANCE,
            orderId,
            redirectUrl: window.encodeURIComponent('https://www.baidu.com'),
            returnUrl: 'https://www.baidu.com',
            quitUrl: 'https://www.baidu.com'
        })
        expect(res.success).toBe(false)
        expect(res.errorType).toBe(PayError.ALIPAY_H5_BREAK)
    })
})


describe('测试用0.9元余额 + 0.1元微信金额支付', () => {
    test('test：获取账户余额', async () => {
        const balance = await globalDatabase.payment.getBalance()
        expect(balance).toBe(0.9)
    })
    test('test: 使用余额+微信支付', async () => {
        const {orderId, money} = await createOrder()
        const res = await globalDatabase.payment.toPay({
            totalAmount: money,
            payType: PayType.WECHAT_BALANCE,
            orderId,
            redirectUrl: window.encodeURIComponent('https://www.baidu.com'),
            returnUrl: 'https://www.baidu.com',
            quitUrl: 'https://www.baidu.com'
        })
        expect(res.success).toBe(false)
        expect(res.errorType).toBe(PayError.WECHAT_H5_BREAK)
    })
})
